Structures
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   compound_values.rst
   point_objects.rst
   accessing_instance_variables.rst
   operations_on_structures.rst
   structures_as_parameters.rst
   call_by_value.rst
   call_by_reference.rst
   rectangles.rst
   structures_as_returns_types.rst
   passing_other_types_by_reference.rst
   getting_user_input.rst
   glossary.rst
   Exercises.rst
   mixed_up_code.rst
   coding_practice.rst